import { HazelReader, Vector2 } from "@skeldjs/util";
import { SpawnType, SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ShipStatusData, InnerShipStatus } from "./InnerShipStatus";
import { Hostable } from "../Hostable";
import { Networkable, NetworkableConstructor } from "../Networkable";
export declare enum ElectricalDoorsAirship {
    BottomRightNorth = 0,
    CenterSouth = 1,
    TopRightSouth = 2,
    TopCenterSouth = 3,
    TopLeftSouth = 4,
    CenterLeftEast = 5,
    CenterRightWest = 6,
    TopRightWest = 7,
    TopLeftEast = 8,
    BottomRightWest = 9,
    TopLeftWest = 10,
    CenterLeftWest = 11
}
/**
 * Represents a room object for the Airship map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
export declare class AirshipStatus<RoomType extends Hostable = Hostable> extends InnerShipStatus<RoomType> {
    static roomDoors: Partial<Record<SystemType, number[]>>;
    static electricalRooms: ElectricalDoorsAirship[][];
    initialSpawnCenter: Vector2;
    meetingSpawnCenter: Vector2;
    constructor(room: RoomType, spawnType: SpawnType, netid: number, ownerid: number, flags: number, data?: HazelReader | ShipStatusData);
    getComponent<T extends Networkable>(component: NetworkableConstructor<T>): T | undefined;
    Setup(): void;
    HandleRpc(rpc: RepairSystemMessage): Promise<void>;
    getDoorsInRoom(room: SystemType): number[];
}
